"""
Auto-generated gmb_attributes resource.

DO NOT EDIT THIS FILE MANUALLY.
Run `python scripts/generate_resources.py` to regenerate.
"""

from __future__ import annotations

from typing import TYPE_CHECKING, Any

if TYPE_CHECKING:
    from ..client.base import BaseClient


class GmbAttributesResource:
    """
    gmb_attributes operations.
    """

    def __init__(self, client: BaseClient) -> None:
        self._client = client

    def _build_params(self, **kwargs: Any) -> dict[str, Any]:
        """Build query parameters, filtering None values."""

        def to_camel(s: str) -> str:
            parts = s.split("_")
            return parts[0] + "".join(p.title() for p in parts[1:])

        return {to_camel(k): v for k, v in kwargs.items() if v is not None}

    def _build_payload(self, **kwargs: Any) -> dict[str, Any]:
        """Build request payload, filtering None values."""
        from datetime import datetime

        def to_camel(s: str) -> str:
            parts = s.split("_")
            return parts[0] + "".join(p.title() for p in parts[1:])

        result: dict[str, Any] = {}
        for k, v in kwargs.items():
            if v is None:
                continue
            if isinstance(v, datetime):
                result[to_camel(k)] = v.isoformat()
            else:
                result[to_camel(k)] = v
        return result

    def get_google_business_attributes(self, account_id: str) -> dict[str, Any]:
        """Get Google Business Profile location attributes"""
        return self._client._get(f"/v1/accounts/{account_id}/gmb-attributes")

    def update_google_business_attributes(
        self, account_id: str, attributes: list[dict[str, Any]], attribute_mask: str
    ) -> dict[str, Any]:
        """Update Google Business Profile location attributes"""
        payload = self._build_payload(
            attributes=attributes,
            attribute_mask=attribute_mask,
        )
        return self._client._put(
            f"/v1/accounts/{account_id}/gmb-attributes", data=payload
        )

    async def aget_google_business_attributes(self, account_id: str) -> dict[str, Any]:
        """Get Google Business Profile location attributes (async)"""
        return await self._client._aget(f"/v1/accounts/{account_id}/gmb-attributes")

    async def aupdate_google_business_attributes(
        self, account_id: str, attributes: list[dict[str, Any]], attribute_mask: str
    ) -> dict[str, Any]:
        """Update Google Business Profile location attributes (async)"""
        payload = self._build_payload(
            attributes=attributes,
            attribute_mask=attribute_mask,
        )
        return await self._client._aput(
            f"/v1/accounts/{account_id}/gmb-attributes", data=payload
        )
